@@ -1,12 +1,12 @@
-from . import connection, protocol, log, client, features
+from . import async, connection, protocol, client, features
 
-from .connection import NotConnected, NoMessageAvailable
-from .client import NotInChannel, AlreadyInChannel, BasicClient, ClientPool
-from .features.cap import NEGOTIATING as CAPABILITY_NEGOTIATING, FAILED as CAPABILITY_FAILED, NEGOTIATED as CAPABILITY_NEGOTIATED
+from .async import coroutine, Future
+from .client import Error, NotInChannel, AlreadyInChannel, BasicClient, ClientPool
+from .features.ircv3_1.cap import NEGOTIATING as CAPABILITY_NEGOTIATING, FAILED as CAPABILITY_FAILED, NEGOTIATED as CAPABILITY_NEGOTIATED
 
 __name__ = 'pydle'
-__version__ = '0.7.1'
-__version_info__ = (0, 7, 1)
+__version__ = '0.8.0'
+__version_info__ = (0, 8, 0)
 __license__ = 'BSD'
 
 
