@@ -1,11 +1,11 @@
 ## nickserv.py
 # Support automatic NickServ authentication.
-from .. import client
+from pydle.features import account
 
 __all__ = [ 'NickServSupport' ]
 
 
-class NickServSupport(client.BasicClient):
+class NickServSupport(account.AccountSupport):
     """ Support for NickServ authentication. """
 
     ## Internal overrides.
@@ -13,4 +13,3 @@ class NickServSupport(client.BasicClient):
     def __init__(self, *args, nickserv_password=None, **kwargs):
         self.__init__(*args, **kwargs)
         self.nickserv_password = nickserv_password
-
